@@ -41,6 +41,39 @@ def is_outlier(points, thresh=3.5):
 
     return modified_z_score > thresh
 
+def sort_by_amplitude(pfit,perr):
+    ncomponents = int((len(pfit)-1)//3)
+
+    pfit = np.asarray(pfit)
+    perr = np.asarray(perr)
+
+    # Separate values by type
+    freqs =  pfit[:ncomponents]
+    amps  =  pfit[ncomponents:2*ncomponents]
+    phases = pfit[2*ncomponents:-1]
+
+    freqs_err =  perr[:ncomponents]
+    amps_err  =  perr[ncomponents:2*ncomponents]
+    phases_err = perr[2*ncomponents:-1]
+
+    # Sort values by amplitude
+    keyorder = np.argsort(amps)
+
+    # Sort values
+    freqs  = list(freqs[keyorder])
+    amps   = list(amps[keyorder])
+    phases = list(phases[keyorder])
+
+    freqs_err  = list(freqs_err[keyorder])
+    amps_err   = list(amps_err[keyorder])
+    phases_err = list(phases_err[keyorder])
+
+    # Rearrange results by amplitude
+    pfit = freqs + amps + phases + [pfit[-1]]
+    perr = freqs_err + amps_err + phases_err + [perr[-1]]
+
+    return pfit, perr
+
 class BaseFitter():
     '''
 
@@ -309,7 +342,7 @@ class MultiHarmonicFitter(BaseFitter):
 
         return tmp_pfit
 
-    def fit_harmonics(self,maxharmonics = 3,
+    def fit_harmonics(self,maxharmonics = 3, sigma = 4,
                   absolute_sigma=True,
                   plotting = False, scale='flux',
                   minimum_frequency=None, maximum_frequency=None,
@@ -328,6 +361,8 @@ class MultiHarmonicFitter(BaseFitter):
         maxharmonics : int, default: 3
             The maximum number of harmonics to be fitted. Pass a very large number
             to fit all harmonics, limited by the signal-to-noise ratio.
+        sigma : float, default: 4
+            Signal-to-noise ratio above which a frequency is considered significant and kept.
         absolute_sigma : bool, default: True
             If `True`, error is used in an absolute sense and the estimated parameter covariance
             reflects these absolute values.
@@ -486,6 +521,10 @@ class MultiHarmonicFitter(BaseFitter):
                                                maximum_frequency=(i+1)*best_freq + max(0.5,10*1/np.ptp(self.t)),
                                                samples_per_peak=samples_per_peak)
 
+                # Convert LS power to amplitude
+                power = np.sqrt(4*power/len(self.t))
+
+                # LS may return inf values
                 goodpts = np.isfinite(power)
                 freq = freq[goodpts]
                 power = power[goodpts]
@@ -493,8 +532,8 @@ class MultiHarmonicFitter(BaseFitter):
 
                 df = 1/np.ptp(self.t)
                 umpeak = (freq > (i+1)*best_freq - df) & (freq < (i+1)*best_freq + df)
-                if np.nanmax(np.sqrt(power[umpeak])) <= np.nanmean(np.sqrt(power)) + 3*np.nanstd(np.sqrt(power)):
-                    # peak height < mean + 3 std
+                if np.nanmax(power[umpeak]) / np.nanmean(power) < sigma:
+                    # s/n < sigma
                     break
 
                 # --- Check if best period is longer than 2x data duration ---
@@ -1201,6 +1240,8 @@ class MultiFrequencyFitter(BaseFitter):
                 self.pfit = pfit
                 self.perr = self.get_analytic_uncertainties() + [ np.sqrt(np.diag(pcov))[-1] ]
 
+                self.pfit, self.perr = sort_by_amplitude(self.pfit, self.perr)
+
                 return self.pfit, self.perr
 
             elif error_estimation != 'analytic' and refit is False:
@@ -1295,10 +1336,12 @@ class MultiFrequencyFitter(BaseFitter):
                     self.y = yorig
                     self.pfit = pfit
                     self.perr = perr
+                    self.pfit, self.perr = sort_by_amplitude(self.pfit, self.perr)
                     return self.pfit, self.perr
 
                 self.pfit = pfit
                 self.perr = perr
+                self.pfit, self.perr = sort_by_amplitude(self.pfit, self.perr)
                 return self.pfit, self.perr
 
             elif error_estimation != 'analytic' and refit:
@@ -1343,6 +1386,7 @@ class MultiFrequencyFitter(BaseFitter):
 
                 self.pfit = pfit
                 self.perr = newperr
+                self.pfit, self.perr = sort_by_amplitude(self.pfit, self.perr)
                 return self.pfit, self.perr
 
         except RuntimeError:
@@ -1354,6 +1398,7 @@ class MultiFrequencyFitter(BaseFitter):
 
             self.pfit = np.array([self.freqs, *self.amps, *self.phases, self.zeropoints[0] ])
             self.perr = np.array([self.freqserr, *self.ampserr, *self.phaseserr, self.zeropointerr[0] ])
+            self.pfit, self.perr = sort_by_amplitude(self.pfit, self.perr)
             return self.pfit, self.perr
 
     def get_residual(self):
